@@ -1,5 +1,5 @@
 #! /usr/bin/env python
-# -*- coding: iso-8859-1 -*-
+# -*- coding: utf-8 -*-
 # vi:ts=4:et
 
 import threading
@@ -22,7 +22,7 @@ class WorkerThread(threading.Thread):
         self.curl = pycurl.Curl()
         self.curl.setopt(pycurl.URL, 'http://localhost:8380/success')
         self.curl.setopt(pycurl.SHARE, share)
-        self.sio = util.StringIO()
+        self.sio = util.BytesIO()
         self.curl.setopt(pycurl.WRITEFUNCTION, self.sio.write)
 
     def run(self):
@@ -34,6 +34,7 @@ class ShareTest(unittest.TestCase):
         s = pycurl.CurlShare()
         s.setopt(pycurl.SH_SHARE, pycurl.LOCK_DATA_COOKIE)
         s.setopt(pycurl.SH_SHARE, pycurl.LOCK_DATA_DNS)
+        s.setopt(pycurl.SH_SHARE, pycurl.LOCK_DATA_SSL_SESSION)
 
         t1 = WorkerThread(s)
         t2 = WorkerThread(s)
@@ -46,5 +47,14 @@ class ShareTest(unittest.TestCase):
         
         del s
         
-        self.assertEqual('success', t1.sio.getvalue())
-        self.assertEqual('success', t2.sio.getvalue())
+        self.assertEqual('success', t1.sio.getvalue().decode())
+        self.assertEqual('success', t2.sio.getvalue().decode())
+    
+    def test_share_close(self):
+        s = pycurl.CurlShare()
+        s.close()
+    
+    def test_share_close_twice(self):
+        s = pycurl.CurlShare()
+        s.close()
+        s.close()
